@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11629 2019-06-11 17:44:34Z Lavender $
+# $Id: __init__.py 11977 2020-03-16 18:37:48Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-06-12 01:44:34 +0800 (週三, 12 六月 2019) $
-# $Revision: 11629 $
+# $Date: 2020-03-17 03:37:48 +0900 (週二, 17 三月 2020) $
+# $Revision: 11977 $
 
 import json
 import requests
@@ -32,8 +32,8 @@ else:
 
 class Settings(object):
     # Facebook Nuwa Blog APP
-    ZEPHYRUS_FACEBOOK_DEFAULT_APP_ID = "1435073943305111"
-    ZEPHYRUS_FACEBOOK_DEFAULT_APP_SECRET = "1f0ba7a626695ee0c5419627c2d0a8b9"
+    ZEPHYRUS_FACEBOOK_DEFAULT_APP_ID = "1251674698332603"#"1435073943305111"
+    ZEPHYRUS_FACEBOOK_DEFAULT_APP_SECRET = "d1467e0724e3c46749de6413366bb12e" #"1f0ba7a626695ee0c5419627c2d0a8b9"
     ZEPHYRUS_FACEBOOK_WEBHOOK_VERIFY_TOKEN = "25025529"
     
     ZEPHYRUS_FACEBOOK_FAN_DEFAULT_TEMPLATE = \
@@ -58,7 +58,9 @@ class Settings(object):
         for ele in _settings.ZEPHYRUS_FACEBOOK_PHOTO_TEMPLATES:
             if not ele[0] == "facebook/FacebookPhotoPlugin.html":
                 ZEPHYRUS_FACEBOOK_PHOTO_TEMPLATES.append(ele)
-
+                
+MANAGE_PAGES_STATE = "manage_pages"
+    
 settings = Settings()
 
 def getCommentURL(commentId, 
