@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: cms_plugins.py 11977 2020-03-16 18:37:48Z Lavender $
+# $Id: cms_plugins.py 12010 2020-03-25 07:40:45Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-03-17 02:37:48 +0800 (週二, 17 三月 2020) $
-# $Revision: 11977 $
+# $Date: 2020-03-25 16:40:45 +0900 (週三, 25 三月 2020) $
+# $Revision: 12010 $
 
 import re
 import requests
@@ -65,22 +65,33 @@ def getAccessToken():
     # )
     return FacebookSettings.objects.get().accessToken
     
+POPUP_SCRIPTS = '''
+<script>
+    function popupCallback(str){
+        alert("This is callback:" + str);
+    }
+    function openPopup(){
+        var popupWindow = window.open("%s", "popupWindow", "status=1, height=600, width=600, toolbar=0,resizable=0");
+        popupWindow.window.focus();
+    }
+</script>
+''' % reverse("facebookAuthorizationRedirect")
+    
 def getAuthorizationMsg():
     if not getAccessToken():
         accessMessage = _(
             '<p>We are not authorized to read your fan information, please use the following link:</p>'
-            '<a href="%s" target="_blank">Allow this plugin to read your fan information</a>'
-            '<p>If we are not authorized, we will use crawlers to crawl Facebook fan information, '
-            'which has less features and is less secure.</p>'
+            '<a href="#" id="authorization">Allow this plugin to read your fan information</a>'
+            '<p>If we are not authorized, This will cause restrictions on access to FB fan-specific information '
+            '(e.g. filtering function).</p>'
             ) % reverse("facebookAuthorizationRedirect")
     else:
         accessMessage = _(
             '<p>We have obtained your fan special authorization and'
             ' can read your fan special information normally</p>'
-            '<a href="%s" target="_blank">Re-verify</a>') % reverse("facebookAuthorizationRedirect")
+            '<a href="#" id="authorization">Re-verify</a>') % reverse("facebookAuthorizationRedirect")
             
-    return accessMessage
-        
+    return accessMessage + POPUP_SCRIPTS
         
 def getFanPageId(accessToken, url):
     # get fan page id
