@@ -15,11 +15,19 @@
 # $Date: 2019-05-29 15:23:49 +0900 (週三, 29 五月 2019) $
 # $Revision: 11593 $ 
 
+from django.conf import settings
 from django.conf.urls import url
 
 from . import views
 
 urlpatterns = [
-    url(r'^webhook/', 
-        views.FacebookWebHookView.as_view(), name='facebookWebhook')
-]
\ No newline at end of file
+    url(r'^auth/redirect/$', views.AuthorizationRedirectView.as_view(), name='facebookAuthorizationRedirect'),
+    url(r'^auth/$', 
+        views.FacebookAuthorizationView.as_view(), name='facebookAuthorization')
+]
+
+if "Zephyrus.comment" in settings.INSTALLED_APPS:
+    urlpatterns += [
+        url(r'^webhook/', 
+            views.FacebookWebHookView.as_view(), name='facebookWebhook'),
+    ]
\ No newline at end of file
